The pagecache only contains folios, so this is the right thing to do.

Signed-off-by: Matthew Wilcox (Oracle) <wi...@infradead.org>
---
 mm/filemap.c | 24 ++++++++++++------------
 1 file changed, 12 insertions(+), 12 deletions(-)

diff --git a/mm/filemap.c b/mm/filemap.c
index 654bba53442a..b9f25a2d8312 100644
--- a/mm/filemap.c
+++ b/mm/filemap.c
@@ -1673,33 +1673,33 @@ EXPORT_SYMBOL(page_cache_prev_miss);
  * @index: The page cache index.
  *
  * Looks up the page cache slot at @mapping & @offset.  If there is a
  * page cache page, the head page is returned with an increased refcount.
  *
  * If the slot holds a shadow entry of a previously evicted page, or a
  * swap entry from shmem/tmpfs, it is returned.
  *
  * Return: The head page or shadow entry, %NULL if nothing is found.
  */
-static struct page *mapping_get_entry(struct address_space *mapping,
+static struct folio *mapping_get_entry(struct address_space *mapping,
                pgoff_t index)
 {
        XA_STATE(xas, &mapping->i_pages, index);
-       struct page *page;
+       struct folio *folio;
 
        rcu_read_lock();
 repeat:
        xas_reset(&xas);
-       page = xas_load(&xas);
-       if (xas_retry(&xas, page))
+       folio = xas_load(&xas);
+       if (xas_retry(&xas, folio))
                goto repeat;
        /*
         * A shadow entry of a recently evicted page, or a swap entry from
         * shmem/tmpfs.  Return it without attempting to raise page count.
         */
-       if (!page || xa_is_value(page))
+       if (!folio || xa_is_value(folio))
                goto out;
 
-       if (!page_cache_get_speculative(page))
+       if (!page_cache_get_speculative(&folio->page))
                goto repeat;
 
        /*
@@ -1707,14 +1707,14 @@ static struct page *mapping_get_entry(struct 
address_space *mapping,
         * This is part of the lockless pagecache protocol. See
         * include/linux/pagemap.h for details.
         */
-       if (unlikely(page != xas_reload(&xas))) {
-               put_page(page);
+       if (unlikely(folio != xas_reload(&xas))) {
+               put_folio(folio);
                goto repeat;
        }
 out:
        rcu_read_unlock();
 
-       return page;
+       return folio;
 }
 
 /**
@@ -1757,7 +1757,7 @@ struct page *pagecache_get_page(struct address_space 
*mapping, pgoff_t index,
        struct page *page;
 
 repeat:
-       page = mapping_get_entry(mapping, index);
+       page = &mapping_get_entry(mapping, index)->page;
        if (xa_is_value(page)) {
                if (fgp_flags & FGP_ENTRY)
                        return page;
@@ -1673,33 +1673,33 @@ EXPORT_SYMBOL(page_cache_prev_miss);
  *
  * Looks up the page cache slot at @mapping & @offset.  If there is a
- * page cache page, the head page is returned with an increased refcount.
+ * page cache page, the folio is returned with an increased refcount.
  *
  * If the slot holds a shadow entry of a previously evicted page, or a
@@ -1673,33 +1673,33 @@ EXPORT_SYMBOL(page_cache_prev_miss);
  * swap entry from shmem/tmpfs, it is returned.
  *
- * Return: The head page or shadow entry, %NULL if nothing is found.
+ * Return: The folio or shadow entry, %NULL if nothing is found.
  */
-- 
2.29.2

Reply via email to